@@ -241,6 +241,10 @@ def is_ignored_chromium_message(line):
         # [7072:3412:1209/220659.527:ERROR:simple_index_file.cc(322)] Failed to
         # write the temporary index file
         "Failed to write the temporary index file",
+
+        # Qt 6.9 Beta 3 on GitHub Actions
+        # [978:1041:0311/070551.759339:ERROR:bus.cc(407)]
+        "Failed to connect to the bus: Failed to connect to socket /run/dbus/system_bus_socket: No such file or directory",
     ]
     return any(testutils.pattern_match(pattern=pattern, value=message)
                for pattern in ignored_messages)
@@ -399,24 +403,37 @@ class QuteProc(testprocess.Process):
 
     def _executable_args(self):
         profile = self.request.config.getoption('--qute-profile-subprocs')
+        strace = self.request.config.getoption('--qute-strace-subprocs')
         if hasattr(sys, 'frozen'):
-            if profile:
-                raise RuntimeError("Can't profile with sys.frozen!")
+            if profile or strace:
+                raise RuntimeError("Can't profile/strace with sys.frozen!")
             executable = str(pathlib.Path(sys.executable).parent / 'qutebrowser')
             args = []
         else:
-            executable = sys.executable
+            if strace:
+                executable = 'strace'
+                args = [
+                    "-o",
+                    "qb-strace",
+                    "--output-separately",  # create .PID files
+                    "--write=2",  # dump full stderr data (qb JSON logs)
+                    sys.executable,
+                ]
+            else:
+                executable = sys.executable
+                args = []
+
             if profile:
                 profile_dir = pathlib.Path.cwd() / 'prof'
                 profile_id = '{}_{}'.format(self._instance_id,
                                             next(self._run_counter))
                 profile_file = profile_dir / '{}.pstats'.format(profile_id)
                 profile_dir.mkdir(exist_ok=True)
-                args = [str(pathlib.Path('scripts') / 'dev' / 'run_profile.py'),
+                args += [str(pathlib.Path('scripts') / 'dev' / 'run_profile.py'),
                         '--profile-tool', 'none',
                         '--profile-file', str(profile_file)]
             else:
-                args = ['-bb', '-m', 'qutebrowser']
+                args += ['-bb', '-m', 'qutebrowser']
         return executable, args
 
     def _default_args(self):
@@ -431,8 +448,11 @@ class QuteProc(testprocess.Process):
                 '--qt-flag', 'disable-features=PaintHoldingCrossOrigin',
                 '--qt-arg', 'geometry', '800x600+0+0']
 
-        if self.request.config.webengine and testutils.disable_seccomp_bpf_sandbox():
-            args += testutils.DISABLE_SECCOMP_BPF_ARGS
+        if self.request.config.webengine:
+            if testutils.disable_seccomp_bpf_sandbox():
+                args += testutils.DISABLE_SECCOMP_BPF_ARGS
+            if testutils.use_software_rendering():
+                args += testutils.SOFTWARE_RENDERING_ARGS
 
         args.append('about:blank')
         return args
@@ -532,6 +552,7 @@ class QuteProc(testprocess.Process):
     def before_test(self):
         """Clear settings before every test."""
         super().before_test()
+        self.send_cmd(':clear-messages')
         self.send_cmd(':config-clear')
         self._init_settings()
         self.clear_data()
